@@ -22,6 +22,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Optional;
 import java.util.Set;
+import java.util.stream.Collectors;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -30,10 +31,13 @@ import com.google.gwt.user.client.ui.IsWidget;
 import org.drools.workbench.models.datamodel.oracle.DataType;
 import org.drools.workbench.models.datamodel.oracle.FieldAccessorsAndMutators;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
+import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.CompositeColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.DTCellValue52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
+import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52.TableFormat;
+import org.drools.workbench.models.guided.dtable.shared.model.LimitedEntryCol;
 import org.drools.workbench.models.guided.dtable.shared.model.LimitedEntryConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
 import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableErraiConstants;
@@ -63,6 +67,8 @@ import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOr
 import org.uberfire.ext.widgets.core.client.wizards.WizardPage;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
 
+import static org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY;
+import static org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52.TableFormat.LIMITED_ENTRY;
 import static org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.common.DecisionTableColumnViewUtils.nil;
 
 @Dependent
@@ -123,6 +129,14 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
         super.init(wizard);
 
         setupDefaultValues();
+        setupPatternWrapper();
+    }
+
+    void setupPatternWrapper() {
+        patternWrapper = new PatternWrapper(getEditingPattern().getFactType(),
+                                            getEditingPattern().getBoundName(),
+                                            getEditingPattern().getEntryPointName(),
+                                            getEditingPattern().isNegated());
     }
 
     @Override
@@ -155,13 +169,22 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
     }
 
     void appendColumn() {
-        final Pattern52 pattern = editingPattern();
-
-        presenter.appendColumn(pattern,
-                               editingCol());
+        if (isNewColumn()) {
+            presenter.appendColumn(editingPattern(),
+                                   editingCol());
+        } else {
+            presenter.updateColumn(getOriginalPattern52(),
+                                   originalCondition(),
+                                   editingPattern(),
+                                   editingCol());
+        }
     }
 
     public Pattern52 editingPattern() {
+        return wrappedPattern();
+    }
+
+    private Pattern52 wrappedPattern() {
         editingPattern.setFactType(patternWrapper().getFactType());
         editingPattern.setBoundName(patternWrapper().getBoundName());
         editingPattern.setNegated(patternWrapper().isNegated());
@@ -170,6 +193,28 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
         return editingPattern;
     }
 
+    public Pattern52 getEditingPattern() {
+        return editingPattern;
+    }
+
+    @Override
+    public void setEditingPattern(final PatternWrapper patternWrapper) {
+        setupDefaultValues();
+        setPatternWrapper(patternWrapper);
+
+        fireChangeEvent(patternPage);
+        fireChangeEvent(calculationTypePage);
+        fireChangeEvent(fieldPage);
+        fireChangeEvent(operatorPage);
+        fireChangeEvent(valueOptionsPage);
+        fireChangeEvent(additionalInfoPage);
+    }
+
+    void setPatternWrapper(final PatternWrapper patternWrapper) {
+        this.patternWrapper = patternWrapper;
+        this.editingPattern = extractEditingPattern();
+    }
+
     private Pattern52 extractEditingPattern() {
         final String factType = patternWrapper().getFactType();
         final String boundName = patternWrapper().getBoundName();
@@ -204,21 +249,6 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
         return Optional.ofNullable(patternWrapper).orElse(new PatternWrapper());
     }
 
-    @Override
-    public void setEditingPattern(final PatternWrapper patternWrapper) {
-        this.patternWrapper = patternWrapper;
-        this.editingPattern = extractEditingPattern();
-
-        setupDefaultValues();
-
-        fireChangeEvent(patternPage);
-        fireChangeEvent(calculationTypePage);
-        fireChangeEvent(fieldPage);
-        fireChangeEvent(operatorPage);
-        fireChangeEvent(valueOptionsPage);
-        fireChangeEvent(additionalInfoPage);
-    }
-
     @Override
     public String getEntryPointName() {
         return patternWrapper().getEntryPointName();
@@ -263,12 +293,17 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
 
     @Override
     public Set<String> getAlreadyUsedColumnHeaders() {
-        Set<String> columnNames = new HashSet<>();
+        final List<CompositeColumn<? extends BaseColumn>> conditions = getPresenter().getModel().getConditions();
+        final Set<String> columnNames = new HashSet<>();
 
-        for (CompositeColumn<?> cc : getPresenter().getModel().getConditions()) {
-            for (int iChild = 0; iChild < cc.getChildColumns().size(); iChild++) {
-                columnNames.add(cc.getChildColumns().get(iChild).getHeader());
-            }
+        for (final CompositeColumn<?> condition : conditions) {
+            final List<String> headers = condition
+                    .getChildColumns()
+                    .stream()
+                    .map(BaseColumn::getHeader)
+                    .collect(Collectors.toList());
+
+            columnNames.addAll(headers);
         }
 
         return columnNames;
@@ -294,6 +329,16 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
         return false;
     }
 
+    @Override
+    public boolean isLogicallyInsert() {
+        return false;
+    }
+
+    @Override
+    public boolean isUpdateEngine() {
+        return false;
+    }
+
     @Override
     public String getFactField() {
         return editingCol().getFactField();
@@ -330,7 +375,7 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
 
     @Override
     public boolean isBindable() {
-        return tableFormat() == GuidedDecisionTable52.TableFormat.LIMITED_ENTRY || constraintValue() == BaseSingleFieldConstraint.TYPE_LITERAL;
+        return tableFormat() == LIMITED_ENTRY || constraintValue() == BaseSingleFieldConstraint.TYPE_LITERAL;
     }
 
     public int constraintValue() {
@@ -355,7 +400,7 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
     }
 
     @Override
-    public GuidedDecisionTable52.TableFormat tableFormat() {
+    public TableFormat tableFormat() {
         return model().getTableFormat();
     }
 
@@ -426,16 +471,79 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
     }
 
     void setValueOptionsPageCompleted() {
-        this.valueOptionsPageCompleted = Boolean.TRUE;
+        valueOptionsPageCompleted = Boolean.TRUE;
     }
 
     void setupDefaultValues() {
-        editingPattern = emptyPattern();
-        editingCol = newConditionColumn();
+        if (isNewColumn()) {
+            setupDefaultValuesForANewColumn();
+            resetConstraintValueAndValueOptionsPageStatus();
+            resetFieldAndOperator();
+        } else {
+            setupDefaultValuesForAnExistingColumn();
+            setValueOptionsPageCompleted();
+        }
+    }
+
+    private void setupDefaultValuesForAnExistingColumn() {
+        final Pattern52 clonedPattern52 = getOriginalPattern52().clonePattern();
+        final ConditionCol52 clonedConditionCol52 = clone(originalCondition());
+        final int constraintValueType = originalCondition().getConstraintValueType();
+
+        editingPattern = clonedPattern52;
+        editingCol = clonedConditionCol52;
+        constraintValue = constraintValueType;
+    }
+
+    private void setupDefaultValuesForANewColumn() {
+        final Pattern52 newPattern52 = emptyPattern();
+        final ConditionCol52 newConditionCol52 = newConditionColumn();
+
+        editingPattern = newPattern52;
+        editingCol = newConditionCol52;
+    }
+
+    private void resetConstraintValueAndValueOptionsPageStatus() {
         constraintValue = BaseSingleFieldConstraint.TYPE_UNDEFINED;
         valueOptionsPageCompleted = Boolean.FALSE;
+    }
 
-        resetFieldAndOperator();
+    ConditionCol52 clone(final ConditionCol52 column) {
+        final ConditionCol52 clone;
+
+        if (tableFormat() == LIMITED_ENTRY) {
+            clone = new LimitedEntryConditionCol52() {{
+                setValue(cloneDTCellValue(((LimitedEntryCol) column).getValue()));
+            }};
+        } else {
+            clone = new ConditionCol52();
+        }
+
+        clone.setConstraintValueType(column.getConstraintValueType());
+        clone.setFactField(column.getFactField());
+        clone.setFieldType(column.getFieldType());
+        clone.setHeader(column.getHeader());
+        clone.setOperator(column.getOperator());
+        clone.setValueList(column.getValueList());
+        clone.setDefaultValue(cloneDTCellValue(column.getDefaultValue()));
+        clone.setHideColumn(column.isHideColumn());
+        clone.setParameters(column.getParameters());
+        clone.setWidth(column.getWidth());
+        clone.setBinding(column.getBinding());
+
+        return clone;
+    }
+
+    DTCellValue52 cloneDTCellValue(final DTCellValue52 dcv) {
+        if (dcv == null) {
+            return null;
+        }
+
+        return new DTCellValue52(dcv);
+    }
+
+    ConditionCol52 originalCondition() {
+        return (ConditionCol52) getOriginalColumnConfig52();
     }
 
     void resetFieldAndOperator() {
@@ -482,7 +590,7 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
                                                 this);
     }
 
-    private ConditionCol52 newConditionColumn() {
+    ConditionCol52 newConditionColumn() {
         switch (tableFormat()) {
             case EXTENDED_ENTRY:
                 return new ConditionCol52();
@@ -494,14 +602,14 @@ public class ConditionColumnPlugin extends BaseDecisionTableColumnPlugin impleme
     }
 
     private boolean isExtendedEntryTable() {
-        return tableFormat() == GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY;
+        return tableFormat() == EXTENDED_ENTRY;
     }
 
     GuidedDecisionTable52 model() {
         return presenter.getModel();
     }
 
-    private Pattern52 emptyPattern() {
+    Pattern52 emptyPattern() {
         return new Pattern52().clonePattern();
     }
 
