@@ -32,11 +32,6 @@ import org.drools.workbench.models.datamodel.oracle.DataType;
 import org.drools.workbench.models.datamodel.oracle.DropDownData;
 import org.drools.workbench.models.datamodel.rule.FactPattern;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.ActionRetractFactCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.ActionSetFieldCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.ActionWorkItemCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.ActionWorkItemInsertFactCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.ActionWorkItemSetFieldCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BRLActionColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.BRLActionVariableColumn;
@@ -44,8 +39,6 @@ import org.drools.workbench.models.guided.dtable.shared.model.BRLConditionColumn
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
-import org.drools.workbench.models.guided.dtable.shared.model.LimitedEntryBRLActionColumn;
-import org.drools.workbench.models.guided.dtable.shared.model.LimitedEntryBRLConditionColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
 import org.drools.workbench.screens.guided.dtable.client.widget.analysis.panel.IssueSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
@@ -1053,378 +1046,10 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         assertTrue(callbackValue.containsKey("four"));
     }
 
-    @Test
-    public void newConditionColumn() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY);
-
-        dtPresenter.newConditionColumn();
-
-        verify(view,
-               times(1)).newExtendedEntryConditionColumn();
-        verify(view,
-               never()).newLimitedEntryConditionColumn();
-    }
-
-    @Test
-    public void newLimitedEntryConditionColumn() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY);
-
-        dtPresenter.newConditionColumn();
-
-        verify(view,
-               never()).newExtendedEntryConditionColumn();
-        verify(view,
-               times(1)).newLimitedEntryConditionColumn();
-    }
-
-    @Test
-    public void newConditionBRLFragment() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY);
-
-        dtPresenter.newConditionBRLFragment();
-
-        verify(view,
-               times(1)).newExtendedEntryConditionBRLFragment();
-        verify(view,
-               never()).newLimitedEntryConditionBRLFragment();
-    }
-
-    @Test
-    public void newLimitedEntryConditionBRLFragment() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY);
-
-        dtPresenter.newConditionBRLFragment();
-
-        verify(view,
-               never()).newExtendedEntryConditionBRLFragment();
-        verify(view,
-               times(1)).newLimitedEntryConditionBRLFragment();
-    }
-
-    @Test
-    public void newActionInsertColumn() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY);
-
-        dtPresenter.newActionInsertColumn();
-
-        verify(view,
-               times(1)).newExtendedEntryActionInsertColumn();
-        verify(view,
-               never()).newLimitedEntryActionInsertColumn();
-    }
-
-    @Test
-    public void newLimitedEntryActionInsertColumn() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY);
-
-        dtPresenter.newActionInsertColumn();
-
-        verify(view,
-               never()).newExtendedEntryActionInsertColumn();
-        verify(view,
-               times(1)).newLimitedEntryActionInsertColumn();
-    }
-
-    @Test
-    public void newActionSetColumn() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY);
-
-        dtPresenter.newActionSetColumn();
-
-        verify(view,
-               times(1)).newExtendedEntryActionSetColumn();
-        verify(view,
-               never()).newLimitedEntryActionSetColumn();
-    }
-
-    @Test
-    public void newLimitedEntryActionSetColumn() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY);
-
-        dtPresenter.newActionSetColumn();
-
-        verify(view,
-               never()).newExtendedEntryActionSetColumn();
-        verify(view,
-               times(1)).newLimitedEntryActionSetColumn();
-    }
-
-    @Test
-    public void newActionRetractFact() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY);
-
-        dtPresenter.newActionRetractFact();
-
-        verify(view,
-               times(1)).newExtendedEntryActionRetractFact();
-        verify(view,
-               never()).newLimitedEntryActionRetractFact();
-    }
-
-    @Test
-    public void newLimitedEntryActionRetractFact() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY);
-
-        dtPresenter.newActionRetractFact();
-
-        verify(view,
-               never()).newExtendedEntryActionRetractFact();
-        verify(view,
-               times(1)).newLimitedEntryActionRetractFact();
-    }
-
-    @Test
-    public void newActionWorkItem() {
-        dtPresenter.newActionWorkItem();
-
-        verify(view,
-               times(1)).newActionWorkItem();
-    }
-
-    @Test
-    public void newActionWorkItemSetField() {
-        dtPresenter.newActionWorkItemSetField();
-
-        verify(view,
-               times(1)).newActionWorkItemSetField();
-    }
-
-    @Test
-    public void newActionWorkItemInsertFact() {
-        dtPresenter.newActionWorkItemInsertFact();
-
-        verify(view,
-               times(1)).newActionWorkItemInsertFact();
-    }
-
-    @Test
-    public void newActionBRLFragment() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY);
-
-        dtPresenter.newActionBRLFragment();
-
-        verify(view,
-               times(1)).newExtendedEntryActionBRLFragment();
-        verify(view,
-               never()).newLimitedEntryActionBRLFragment();
-    }
-
-    @Test
-    public void newLimitedEntryActionBRLFragment() {
-        dtPresenter.getModel().setTableFormat(GuidedDecisionTable52.TableFormat.LIMITED_ENTRY);
-
-        dtPresenter.newActionBRLFragment();
-
-        verify(view,
-               never()).newExtendedEntryActionBRLFragment();
-        verify(view,
-               times(1)).newLimitedEntryActionBRLFragment();
-    }
-
     @Test
     public void editConditionWithPatternAndCondition() {
         dtPresenter.editCondition(mock(Pattern52.class),
                                   mock(ConditionCol52.class));
-
-        verify(view,
-               times(1)).editCondition(any(Pattern52.class),
-                                       any(ConditionCol52.class));
-    }
-
-    @Test
-    public void editConditionWithBRLCondition() {
-        dtPresenter.editCondition(mock(BRLConditionColumn.class));
-
-        verify(view,
-               times(1)).editExtendedEntryConditionBRLFragment(any(BRLConditionColumn.class));
-        verify(view,
-               never()).editLimitedEntryConditionBRLFragment(any(LimitedEntryBRLConditionColumn.class));
-    }
-
-    @Test
-    public void editLimitedEntryConditionWithBRLCondition() {
-        dtPresenter.editCondition(mock(LimitedEntryBRLConditionColumn.class));
-
-        verify(view,
-               never()).editExtendedEntryConditionBRLFragment(any(BRLConditionColumn.class));
-        verify(view,
-               times(1)).editLimitedEntryConditionBRLFragment(any(LimitedEntryBRLConditionColumn.class));
-    }
-
-    @Test
-    public void editActionWorkItemSetFieldColumn() {
-        dtPresenter.editAction(mock(ActionWorkItemSetFieldCol52.class));
-
-        verify(view,
-               times(1)).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editActionSetFieldColumn() {
-        dtPresenter.editAction(mock(ActionSetFieldCol52.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               times(1)).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editActionWorkItemInsertFactColumn() {
-        dtPresenter.editAction(mock(ActionWorkItemInsertFactCol52.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               times(1)).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editActionInsertFactColumn() {
-        dtPresenter.editAction(mock(ActionInsertFactCol52.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               times(1)).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editActionRetractFactColumn() {
-        dtPresenter.editAction(mock(ActionRetractFactCol52.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               times(1)).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editActionWorkItemColumn() {
-        dtPresenter.editAction(mock(ActionWorkItemCol52.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               times(1)).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editLimitedEntryBRLActionColumn() {
-        dtPresenter.editAction(mock(LimitedEntryBRLActionColumn.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               times(1)).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               never()).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
-    }
-
-    @Test
-    public void editBRLActionColumn() {
-        dtPresenter.editAction(mock(BRLActionColumn.class));
-
-        verify(view,
-               never()).editActionWorkItemSetField(any(ActionWorkItemSetFieldCol52.class));
-        verify(view,
-               never()).editActionSetField(any(ActionSetFieldCol52.class));
-        verify(view,
-               never()).editActionWorkItemInsertFact(any(ActionWorkItemInsertFactCol52.class));
-        verify(view,
-               never()).editActionInsertFact(any(ActionInsertFactCol52.class));
-        verify(view,
-               never()).editActionRetractFact(any(ActionRetractFactCol52.class));
-        verify(view,
-               never()).editActionWorkItem(any(ActionWorkItemCol52.class));
-        verify(view,
-               never()).editLimitedEntryActionBRLFragment(any(LimitedEntryBRLActionColumn.class));
-        verify(view,
-               times(1)).editExtendedEntryActionBRLFragment(any(BRLActionColumn.class));
     }
 
     @Test
